#include "Defs.h"
#include "RPGApp.h"
#include "RPGWindow.h"


//--------------------------------------------------
//	Implementation of the RPGWindow class
//--------------------------------------------------

// A big happy constructor
RPGWindow::RPGWindow(BRect frame, char *title)
	: BWindow(	frame, title, B_TITLED_WINDOW,
				B_NOT_RESIZABLE | B_NOT_ZOOMABLE)
{
	// Add the menu
	BRect		menuframe = Bounds();
	BMenuBar	*menubar;
	BMenu		*menu;
	
	menubar = new BMenuBar(menuframe, "menubar");
	
	menu = new BMenu("File");
	menu->AddItem(new BMenuItem("Quit", new BMessage(MENU_FILE_QUIT), 'Q'));
	menubar->AddItem(menu);
	
	menu = new BMenu("Help");
	menu->AddItem(new BMenuItem("About...", new BMessage(MENU_HELP_ABOUT), 'A'));
	menubar->AddItem(menu);
	
	AddChild(menubar);
	
	// Add the chexboxes
	BCheckBox *checkBox;
	checkBox = new BCheckBox(BRect(CHECKBOXES_X1, UP_CHECKBOX_Y1, CHECKBOXES_X2,
		CHECKBOXES_Y2), "upper case box", "Include upper case letters",
		new BMessage(UPPER_CASE_BOX));
	if (((RPGApp *)be_app)->IsUpCase()) checkBox->SetValue(B_CONTROL_ON);
	AddChild(checkBox);
	
	checkBox = new BCheckBox(BRect(CHECKBOXES_X1, LO_CHECKBOX_Y1, CHECKBOXES_X2,
		CHECKBOXES_Y2), "lower case box", "Include lower case letters",
		new BMessage(LOWER_CASE_BOX));
	if (((RPGApp *)be_app)->IsLoCase()) checkBox->SetValue(B_CONTROL_ON);
	AddChild(checkBox);
	
	checkBox = new BCheckBox(BRect(CHECKBOXES_X1, NB_CHECKBOX_Y1, CHECKBOXES_X2,
		CHECKBOXES_Y2), "numbers box", "Include numbers",
		new BMessage(NUMBERS_BOX));
	if (((RPGApp *)be_app)->IsNumbers()) checkBox->SetValue(B_CONTROL_ON);
	AddChild(checkBox);
	
	// Add the TextControls
	kDNTextControl = new BTextControl(BRect(TCS_X1, TCD_Y1, TCS_X2, 0), "d_nb text control",
		"Number of digits per password", "", new BMessage(TC_DG_NB));
	BString DigitNb;
	DigitNb<<((RPGApp *)be_app)->DgNb();
	kDNTextControl->SetText(DigitNb.String());
	AddChild(kDNTextControl);
	
	kPNTextControl = new BTextControl(BRect(TCS_X1, TCP_Y1, TCS_X2, 0), "p_nb text control",
		"Number of passwords", "", new BMessage(TC_PW_NB));
	BString PasswordNb;
	PasswordNb<<((RPGApp *)be_app)->PwNb();
	kPNTextControl->SetText(PasswordNb.String());
	AddChild(kPNTextControl);
	
	// Add the button
	BButton *button;
	button = new BButton(BRect(BUTTON_X1, BUTTON_Y1, BUTTON_X2, 0), "button",
		"Generate", new BMessage(BUTTON_PRESSED));
	AddChild(button);	
}


// Process the messages received by the application
void RPGWindow::MessageReceived(BMessage *message)
{
	switch (message->what)
	{
		case MENU_FILE_QUIT:
			be_app->PostMessage(B_QUIT_REQUESTED);
			break;
		
		case MENU_HELP_ABOUT:
			be_app->PostMessage(B_ABOUT_REQUESTED);
			break;
		
		case UPPER_CASE_BOX:
			((RPGApp *)be_app)->ChangeUpCase();
			break;
		
		case LOWER_CASE_BOX:
			((RPGApp *)be_app)->ChangeLoCase();
			break;
		
		case NUMBERS_BOX:
			((RPGApp *)be_app)->ChangeNumbers();
			break;
		
		case TC_DG_NB:
			int32 digitNb;
			digitNb = atoi(kDNTextControl->Text());
			if (digitNb <= 0)
				((RPGApp *)be_app)->Alert("Please enter an interger greater than zero", 
					"ok", B_STOP_ALERT);
			((RPGApp *)be_app)->SetDgNb(digitNb);
			break;
		
		case TC_PW_NB:
			int32 passwordNb;
			passwordNb = atoi(kPNTextControl->Text());
			if (passwordNb <= 0)
				((RPGApp *)be_app)->Alert("Please enter an interger greater than zero", 
					"ok", B_STOP_ALERT);
			((RPGApp *)be_app)->SetPwNb(passwordNb);
			break;
		
		case BUTTON_PRESSED:
			if (!((RPGApp *)be_app)->IsUpCase() &&
				!((RPGApp *)be_app)->IsLoCase() &&
				!((RPGApp *)be_app)->IsNumbers())
			{
				((RPGApp *)be_app)->Alert("You must include at least one of the three:\n\n"
					"upper case letters\n"
					"lower case letters\n"
					"or numbers",
					"I think that too...", B_STOP_ALERT);
				break;
			}
			((RPGApp *)be_app)->GeneratePasswords();
			break;
		
		default:
			BWindow::MessageReceived(message);
			break;
	}
}


// Have to quit...
bool RPGWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return BWindow::QuitRequested();
}
